config

package
v0.0.0-...-e4649f2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 6, 2022 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package config exposes the service configuration, by consuming the configs from the config_file.yml file.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Config

type Config struct {
	Port            string
	Partitions      int
	PartitionBuffer int
}

Config exposes app initialization configuration.

func GetConfig

func GetConfig() Config

GetConfig reads the config file and instantiates the Config data.

Jump to