package
Version:
v0.0.0-...-e4649f2
Opens a new window with list of versions in this module.
Published: May 6, 2022
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package config exposes the service configuration, by consuming the configs from the config_file.yml file.
type Config struct {
Port string
Partitions int
PartitionBuffer int
}
Config exposes app initialization configuration.
GetConfig reads the config file and instantiates the Config data.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.